Module io

Module io 

Streaming input/output adapters for query execution.

NDJSON adapters evaluate each non-empty row independently while reusing the caller’s crate::JetroEngine plan, VM, and tape execution caches.

Structs

NdjsonExecutionReport
NdjsonExecutionStats
NdjsonOptions
Configuration for per-row NDJSON execution.
NdjsonPerRowDriver
Forward-only per-row NDJSON reader.
NdjsonRevDistinctStats
NdjsonReverseFileDriver
Reverse NDJSON line reader over a seekable file.
NdjsonRouteExplain
NdjsonSourceCaps

Enums

DistinctFrontFilterKind
NdjsonControl
NdjsonFallbackReason
NdjsonNullOutput
NdjsonParallelism
NdjsonRouteKind
NdjsonRowFrame
NdjsonRowsPlanKind
NdjsonSource
Input source for NDJSON APIs that can operate on either files or callers’ existing buffered readers.
NdjsonSourceMode
NdjsonWriterPathKind
NullPayload
RowError
Error with enough row context for users to find malformed input quickly.

Functions

collect_ndjson
collect_ndjson_file
collect_ndjson_file_with_options
collect_ndjson_matches
collect_ndjson_matches_file
collect_ndjson_matches_file_with_options
collect_ndjson_matches_source
collect_ndjson_matches_source_with_options
collect_ndjson_matches_with_options
collect_ndjson_rev
collect_ndjson_rev_matches
collect_ndjson_rev_matches_with_options
collect_ndjson_rev_with_options
collect_ndjson_source
collect_ndjson_source_with_options
collect_ndjson_with_options
for_each_ndjson
for_each_ndjson_rev
for_each_ndjson_rev_with_options
for_each_ndjson_source
for_each_ndjson_source_until
for_each_ndjson_source_until_with_options
for_each_ndjson_source_with_options
for_each_ndjson_until
for_each_ndjson_until_with_options
for_each_ndjson_with_options
ndjson_explain
ndjson_rows_plan_kind
ndjson_writer_path_kind
run_ndjson
run_ndjson_file
run_ndjson_file_limit
run_ndjson_file_limit_with_options
run_ndjson_file_limit_with_report
run_ndjson_file_limit_with_report_and_options
run_ndjson_file_with_options
run_ndjson_file_with_report
run_ndjson_file_with_report_and_options
run_ndjson_limit
run_ndjson_limit_with_options
run_ndjson_limit_with_report
run_ndjson_limit_with_report_and_options
run_ndjson_matches
run_ndjson_matches_file
run_ndjson_matches_file_with_options
run_ndjson_matches_file_with_report
run_ndjson_matches_file_with_report_and_options
run_ndjson_matches_source
run_ndjson_matches_source_with_options
run_ndjson_matches_source_with_report
run_ndjson_matches_source_with_report_and_options
run_ndjson_matches_with_options
run_ndjson_matches_with_report
run_ndjson_matches_with_report_and_options
run_ndjson_rev
run_ndjson_rev_distinct_by
run_ndjson_rev_distinct_by_with_options
run_ndjson_rev_distinct_by_with_report
run_ndjson_rev_distinct_by_with_report_and_options
run_ndjson_rev_distinct_by_with_stats
run_ndjson_rev_distinct_by_with_stats_and_options
run_ndjson_rev_limit
run_ndjson_rev_limit_with_options
run_ndjson_rev_matches
run_ndjson_rev_matches_with_options
run_ndjson_rev_matches_with_report
run_ndjson_rev_matches_with_report_and_options
run_ndjson_rev_with_options
run_ndjson_source
run_ndjson_source_limit
run_ndjson_source_limit_with_options
run_ndjson_source_limit_with_report
run_ndjson_source_limit_with_report_and_options
run_ndjson_source_with_options
run_ndjson_source_with_report
run_ndjson_source_with_report_and_options
run_ndjson_with_options
run_ndjson_with_report
run_ndjson_with_report_and_options