Phi

Struct Phi 

pub struct Phi {
    pub id: ValueId,
    pub incoming: Vec<(PhiEdge, ValueId)>,
}
A phi node: at a merge point, value takes one of several incoming values depending on which predecessor path was taken.

Fields

id: ValueIdincoming: Vec<(PhiEdge, ValueId)>

Incoming (predecessor label, value) pairs.